Improve this doc

# Error: $parse:isecfld
Referencing Disallowed Field in Expression

    Attempting to access a disallowed field in Angular expressions! Expression: {0}

## Description

Occurs when an expression attempts to access one of the following fields:

- proto
- defineGetter
- defineSetter
- lookupGetter
- lookupSetter

AngularJS bans access to these fields from within expressions since access is a known way to mess with native objects or to execute arbitrary Javascript code.

To resolve this error, avoid using these fields in expressions. As a last resort, alias their value and access them through the alias instead.

Example expressions that would result in this error:

    <div>{{user.__proto__.hasOwnProperty = $emit}}</div>

    <div>{{user.__defineGetter__('name', noop)}}</div>